Extraction template, request, and result types
Structs
- Extraction
Metadata - Metadata about an extraction result
- Extraction
Request - Request to extract data from a page using a template
- Extraction
Result - Result of a successful extraction
- Extraction
Template - A reusable extraction template defining how to extract data from a page
- Region
- A named region within a template to extract data from
- Region
Status - Status of extraction for a single region
- Template
Metadata - Metadata about a template