MCP plugin server implementation
Provides the core tool definitions and request handling for plugin extraction.
Structs
- McpPlugin
Server - MCP server providing plugin extraction tools
MCP plugin server implementation
Provides the core tool definitions and request handling for plugin extraction.